Index: branches/eam_branches/ipp-20120905/Ohana/src/libdvo/include/dvo.h
===================================================================
--- branches/eam_branches/ipp-20120905/Ohana/src/libdvo/include/dvo.h	(revision 34728)
+++ branches/eam_branches/ipp-20120905/Ohana/src/libdvo/include/dvo.h	(revision 34735)
@@ -193,4 +193,5 @@
   ID_PHOTOM_PASS_3    = 0x00000800, // average magnitude calculated in 3th pass
   ID_PHOTOM_PASS_4    = 0x00001000, // average magnitude calculated in 4th pass
+  ID_PSPS_OBJ_EXT     = 0x00002000, // In PSPS ID_SECF_OBJ_EXT is moved here so it fits within 16 bits
   ID_SECF_OBJ_EXT     = 0x01000000, // extended in this band
 } DVOSecfiltFlags;

Index: branches/eam_branches/ipp-20120905/Ohana/src/addstar/src/psps_ids.c
===================================================================
--- branches/eam_branches/ipp-20120905/Ohana/src/addstar/src/psps_ids.c	(revision 34728)
+++ branches/eam_branches/ipp-20120905/Ohana/src/addstar/src/psps_ids.c	(revision 34735)
@@ -21,5 +21,5 @@
 CreatePSPSStackDetectionID(int sourceID, int imageID, int detID)
 {
   // sourceID : ID of database + table that tracked the image (< 0x100 = 256)
   // imageID : external ID of the image which provided the detections (< 0x1000.0000 ~ 2.7e8)
   // detID : detection sequence in image (< 0x1000.0000 ~ 2.7e8)
@@ -27,5 +27,5 @@
   assert (detID    < 0x10000000);
   assert (imageID  < 0x10000000);
-  assert (sourceID < 0x100);
+  assert (sourceID < 0x7f);
   
   uint64_t detectid = ((uint64_t)sourceID << 56) + ((uint64_t)imageID << 28) + (uint64_t)detID;
@@ -21,5 +21,5 @@
 CreatePSPSStackDetectionID(int sourceID, int imageID, int detID)
 {
-  // sourceID : ID of database + table that tracked the image (< 0x100 = 256)
+  // sourceID : ID of database + table that tracked the image (< 0x7f = 127)
   // imageID : external ID of the image which provided the detections (< 0x1000.0000 ~ 2.7e8)
   // detID : detection sequence in image (< 0x1000.0000 ~ 2.7e8)